sample module — deprecation 2.0.7 documentation

# `sample` module

The following documents the `sample` module to show what documentation looks like when `deprecated()` has modified it.

class `sample.` `Tests`(methodName='runTest')

`sample.` `multiline_bottom`()

  This function returns 1.

  Multiline Bottom. Deprecation Note is inserted at the bottom.

  This is also here to show that multiline docstrings work

  Deprecated since version 1.0: This will be removed in 2.0. Use the `multiline_one` function instead.

`sample.` `multiline_top`()

  This function returns 1.

  Deprecated since version 1.0: This will be removed in 2.0. Use the `multiline_one` function instead.

  Multiline Top. Deprecation Note is inserted above this line. This is done via setting `deprecation.message_location` to ‘top’.

  This is also here to show that multiline docstrings work

`sample.` `one`()

  This function returns 1

`sample.` `uno`()

  Esta función regresa 1

  This is Spanish for ‘This function returns 1’

  This is also here to show that multiline docstrings work

  Deprecated since version 1.0: This will be removed in 2.0. Use the `one` function instead

`sample.` `why`()

  This isn’t necessary

  Deprecated since version 1.0: This will be removed in 1.5. Why would you ever do this anyway?

`sample.` `won`()

  This function returns 1

  Deprecated since version 1.0: This will be removed in 2.0. Use the `one` function instead